import { sequelize } from '@kevisual/code-center-module';
import { DataTypes, Model } from 'sequelize';
export type Provider = Partial<InstanceType<typeof ProviderModel>>;

type ModelItem = {
  /**
   * 模型
   */
  model: string;
  /**
   * 提供者
   */
  provider: string;
  /**
   * 配置， 自有配置
   */
  config: Record<string, any>;
  /**
   * 标题
   */
  title: string;
  /**
   * 描述
   */
  description: string;
};
export type ProviderData = {
  models: ModelItem[];
  config: Record<string, any>; // 共享配置
};
export class ProviderModel extends Model {
  declare id: string;
  declare title: string;
  declare description: string;

  declare config: Record<string, any>;
  declare data: Record<string, any>;

  declare uid: string;
  declare createdAt: Date;
  declare updatedAt: Date;
}

ProviderModel.init(
  {
    id: {
      type: DataTypes.UUID,
      primaryKey: true,
      defaultValue: DataTypes.UUIDV4,
      comment: 'id',
    },
    title: {
      type: DataTypes.TEXT,
      defaultValue: '',
    },
    description: {
      type: DataTypes.TEXT,
      defaultValue: '',
    },
    config: {
      type: DataTypes.JSON,
      defaultValue: {},
    },
    data: {
      type: DataTypes.JSON,
      defaultValue: {},
    },
    uid: {
      type: DataTypes.UUID,
      allowNull: true,
    },
  },
  {
    sequelize,
    tableName: 'kv_provider',
    paranoid: true,
  },
);
